@@ -7,9 +7,8 @@ use eyre::bail;
 use path_absolutize::Absolutize;
 
 use crate::cli::args::ToolArg;
-use crate::config::Config;
-use crate::file;
 use crate::file::{make_symlink, remove_all};
+use crate::{config, file};
 
 /// Symlinks a tool version into mise
 ///
@@ -33,7 +32,6 @@ pub struct Link {
 
 impl Link {
     pub fn run(self) -> Result<()> {
-        let config = Config::try_get()?;
         let version = match self.tool.tvr {
             Some(ref tvr) => tvr.version(),
             None => bail!("must provide a version for {}", self.tool.style()),
@@ -60,7 +58,7 @@ impl Link {
         file::create_dir_all(target.parent().unwrap())?;
         make_symlink(&path, &target)?;
 
-        config.rebuild_shims_and_runtime_symlinks()
+        config::rebuild_shims_and_runtime_symlinks(&[])
     }
 }
 
