@@ -1,7 +1,7 @@
 use std::path::{Path, PathBuf};
 
 use console::{style, Term};
-use eyre::{eyre, Result};
+use eyre::{bail, eyre, Result};
 use itertools::Itertools;
 use path_absolutize::Absolutize;
 
@@ -155,7 +155,6 @@ impl Use {
                         if let ToolRequest::Version {
                             version: _version,
                             source,
-                            os,
                             options,
                             backend,
                         } = request
@@ -163,7 +162,6 @@ impl Use {
                             request = ToolRequest::Version {
                                 version: tv.version.clone(),
                                 source,
-                                os,
                                 options,
                                 backend,
                             };
@@ -179,7 +177,7 @@ impl Use {
             self.warn_if_hidden(&config, cf.get_path());
         }
         for plugin_name in &self.remove {
-            cf.remove_plugin(plugin_name)?;
+            cf.remove_tool(plugin_name)?;
         }
         cf.save()?;
 
@@ -252,6 +250,9 @@ impl Use {
     }
 
     fn tool_selector(&self) -> Result<ToolArg> {
+        if !console::user_attended_stderr() {
+            bail!("No tool specified and not running interactively");
+        }
         let mut s = demand::Select::new("Tools")
             .description("Select a tool to install")
             .filtering(true)
