@@ -773,6 +773,11 @@ const completionSpec: Fig.Spec = {
               description: "Do not print table header",
               isRepeatable: false,
             },
+            {
+              name: "--tracked-configs",
+              description: "List all tracked config files",
+              isRepeatable: false,
+            },
             {
               name: ["-J", "--json"],
               description: "Output in JSON format",
@@ -827,6 +832,11 @@ const completionSpec: Fig.Spec = {
           description: "Do not print table header",
           isRepeatable: false,
         },
+        {
+          name: "--tracked-configs",
+          description: "List all tracked config files",
+          isRepeatable: false,
+        },
         {
           name: ["-J", "--json"],
           description: "Output in JSON format",
@@ -1351,6 +1361,11 @@ const completionSpec: Fig.Spec = {
             debounce: true,
           },
         },
+        {
+          name: "--prunable",
+          description: "List only tools that can be pruned with `mise prune`",
+          isRepeatable: false,
+        },
         {
           name: "--no-header",
           description: "Don't display headers",
@@ -2739,6 +2754,13 @@ const completionSpec: Fig.Spec = {
     {
       name: ["version", "v"],
       description: "Display the version of mise",
+      options: [
+        {
+          name: ["-J", "--json"],
+          description: "Print the version information in JSON format",
+          isRepeatable: false,
+        },
+      ],
     },
     {
       name: ["watch", "w"],
